@@ -94,7 +94,8 @@ def get_transaction_result(web3: Web3, tx_hash, result_type):
     if result_type == 'receipt':
         return receipt
     if result_type == 'event':
-        return InnerContractEvent.get_event(receipt)
+        from platon_aide.base import Event
+        return Event(InnerContractEvent.get_event(receipt))
 
 
 def contract_call(func):
@@ -141,10 +142,7 @@ def contract_transaction(func):
         if self._result_type == 'txn':
             return txn
 
-        try:
-            return self.send_transaction(txn, private_key, self._result_type)
-        except ContractLogicError as e:
-            return e
+        return self.send_transaction(txn, private_key, self._result_type)
 
     return wrapper
 
